<script setup>
import {onMounted, reactive, ref} from "vue";
import {changeDriveInfoModule} from "@/views/moudle/driveInf/driveInf";
const form = ref(null);
import {
	ElLoading,
	ElMessage
} from "element-plus";
const props = defineProps({
	visible: {
		type: Boolean,
		default: false
	}
});
const emit = defineEmits(["update:visible", "success"]);

const layout = reactive({
	gutter: 16,
	span: 12
});

const params = reactive({
	name: "",
	boxSn: "",
});

const rules = reactive({
	name: [
		{ required: true, message: '请输入车辆名称', trigger: 'blur' },
	],
	boxSn: [
		{ required: true, message: '请输入车辆编码', trigger: 'blur' },
	]
});

const close = ()=>{
	emit("update:visible", false);
}

const submitForm = async (form) => {
	if (!form) return
	await form.validate((valid, fields) => {
		if (valid) {
			handleAdd();
		} else {
			console.log('error submit!', fields)
		}
	});
}

const {
	addDrive
} = changeDriveInfoModule();

const handleAdd = async ()=>{
	const loading = ElLoading.service({
		text: "数据加载中...",
		background: "rgba(122, 122, 122, 0.5)"
	});
	try {
		const rs = await addDrive(params.name, params.boxSn);
		loading.close();
		if(rs.code === 1) {
			ElMessage({
				message: rs.message,
				type: "success"
			});
			emit('success');
			close();
		}else {
			ElMessage.error(rs.message);
		}
	}catch (e) {
		console.log(e);
		loading.close();
	}
}

onMounted(()=>{

});
</script>

<template>
	<div class="params-container">
		<div class="params-content">
			<el-form
				ref="form"
				:model="params"
				:rules="rules"
				label-position="top">
				<el-row :gutter="layout.gutter">
					<el-col :span="layout.span">
						<el-form-item label="车辆名称" prop="name">
							<el-input v-model="params.name" />
						</el-form-item>
					</el-col>
					<el-col :span="layout.span">
						<el-form-item label="车辆编码" prop="boxSn">
							<el-input v-model="params.boxSn" />
						</el-form-item>
					</el-col>
				</el-row>
			</el-form>
		</div>
		<div class="params-footer">
			<el-button type="primary" @click="submitForm(form)">添加</el-button>
			<el-button type="primary" @click="close">取消</el-button>
		</div>
	</div>
</template>

<style scoped lang="less">
.params-container {
	width: 600px;
	background-color: #FFFFFF;
	.params-content {
		padding: 8px;
	}
	.params-footer {
		padding: 8px;
		text-align: right;
	}
}
</style>
